Structs
- Parallel
Map - Tasks is a structure type that captures the information necessary to run the values within the Iterator in parallel Its the result of parallel_task that can be run on any Iterator implementing type.
Traits
- Parallel
MapIter - ParallelMapIter allows calling the .map(f) on type implementing AtomicIterator to get a ParallelMap object on which collect may be called.