pub enum ThreadPrioritization {
Remaining,
RateOfChange,
ChangeFromLastPoll,
}Expand description
ThreadPrioritization is the default approach passed to Worker Controller, used for prioritization of threads within the library.
Variants